from setuptools import setup
from setuptools import find_packages

setup(
    name = "grep-result",
    version = "0.0.2",
    packages=find_packages(),
    author="llby",
    author_email="llby@shingor.net",
    license="MIT",
    classifiers=["Topic :: Utilities"]
)
